Cursor

Struct Cursor 

pub struct Cursor<D: SymbolDomain> { /* private fields */ }
A matching cursor carrying independent source and subject positions.

use sim_lib_pattern::{ByteDomain, ByteOffset, CodeUnitDomain, CodeUnitOffset, Cursor};

fn run_bytes(_: Cursor<ByteDomain>) {}
let text_cursor = Cursor::<CodeUnitDomain>::new(CodeUnitOffset::new(0), CodeUnitOffset::new(0));
run_bytes(text_cursor);

Implementations

Source

impl<D: SymbolDomain> Cursor<D>

pub const fn new(source: D::Offset, subject: D::Offset) -> Self

Creates a cursor from its pattern-source and subject positions.

pub const fn source_position(&self) -> D::Offset

Returns the position in the pattern source.

pub const fn subject_position(&self) -> D::Offset

Returns the position in the matched subject.

pub const fn advanced(self, source: D::Offset, subject: D::Offset) -> Self

Returns a cursor advanced to new source and subject positions.