TextOp

Enum TextOp 

pub enum TextOp {
    Class(TextClass),
    Literal(char),
    Any,
    CaptureStart,
    CaptureEnd,
    Repeat {
        min: usize,
        max: Option<usize>,
        greedy: bool,
    },
    Balanced {
        open: char,
        close: char,
    },
    Frontier(TextClass),
    AnchorStart,
    AnchorEnd,
}
One operation in the shared text-pattern VM.

Variants



Class(TextClass)

Match one character from a class.



Literal(char)

Match one literal character.



Any

Match any one character.



CaptureStart

Start a capture at the current byte offset.



CaptureEnd

End the most recent open capture at the current byte offset.



Repeat

Quantify the previous consuming operation.

Fields

min: usize

Minimum number of repetitions.

max: Option<usize>

Maximum number of repetitions, or unbounded when absent.

greedy: bool

Prefer longer repetitions before shorter ones.



Balanced

Match balanced text beginning with open and ending at its paired close.

Fields

open: char

Opening delimiter.

close: char

Closing delimiter.



Frontier(TextClass)

Match a frontier before a character in the class.



AnchorStart

Match the start of the subject.



AnchorEnd

Match the end of the subject.