pub fn exhaustiveness_diagnostics(
adt: &AlgebraicDataType,
arms: &[MatchArm],
) -> Vec<Diagnostic>Expand description
Returns diagnostics for any adt variants not covered by arms.
Returns an empty vector when the arms cover every variant; otherwise a single error diagnostic listing the missing variants.