pub trait BoundedExtension {
type Work;
// Required methods
fn start(
&self,
kind: ExtensionKind,
) -> Option<Vec<ExtensionWork<Self::Work>>>;
fn step(&self, work: Self::Work) -> ExtensionStep<Self::Work>;
}Expand description
Opt-in implementation of one non-regular feature family.
Required Associated Types
Required Methods
Sourcefn start(&self, kind: ExtensionKind) -> Option<Vec<ExtensionWork<Self::Work>>>
fn start(&self, kind: ExtensionKind) -> Option<Vec<ExtensionWork<Self::Work>>>
Reports whether this implementation admits kind and creates initial work.
Sourcefn step(&self, work: Self::Work) -> ExtensionStep<Self::Work>
fn step(&self, work: Self::Work) -> ExtensionStep<Self::Work>
Evaluates exactly one item. Implementations continue through returned work, never by recursively invoking the executor.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".